@@ -39,6 +39,7 @@ HyperAgentLlm = Literal[
     "gpt-4.1-nano",
 ]
 ClaudeComputerUseLlm = Literal[
+    "claude-haiku-4-5-20251001",
     "claude-sonnet-4-5",
     "claude-sonnet-4-20250514",
     "claude-3-7-sonnet-20250219",
@@ -48,6 +49,9 @@ SessionRegion = Literal[
     "us-central",
     "asia-south",
     "us-dev",
+    "europe-west",
+    "us-west",
+    "us-east",
 ]
 
 Country = Literal[
